package logs

import (
	"fmt"
	"strings"
	"path/filepath"

	"github.com/sirupsen/logrus"
)

// LogTextFormatter is a custom log formatter for text output
type LogTextFormatter struct {
	logrus.Formatter
}

// Format helps formatting time to UTC
func (u LogTextFormatter) Format(e *logrus.Entry) ([]byte, error) {
	timestamp := e.Time.Format("2006-01-02 15:04:05.000")
	level := strings.ToUpper(e.Level.String())
	message := e.Message
	file := filepath.Base(e.Caller.File)
	line := e.Caller.Line

	return []byte(fmt.Sprintf("%s [%s] %s:%d %s\n", timestamp, level, file, line, message)), nil
}

